<?php

/**
 * @param $form
 * @param $form_state
 *
 * @return mixed
 */
function connectid_admin_form($form, &$form_state) {

  $form['oauth_info'] = [
    '#type' => 'fieldset',
    '#title' => t('OAuth'),
    '#description' => t("Those information are essential to connect to the API"),
    '#tree' => FALSE,
    '#collappsible' => TRUE,
    '#collapsed' => TRUE,
  ];


  if (module_exists('key')) {
    // TODO
  }
  else {
    $form['oauth_info']['connectid_oauth_id'] = [
      '#type' => 'textfield',
      '#title' => t("OAuth ID"),
      '#description' => t("Client ID given by MediaConnect"),
      '#default_value' => variable_get('connectid_oauth_id', ''),
    ];
    $form['oauth_info']['connectid_oauth_secret'] = [
      '#type' => 'textfield',
      '#title' => t("OAuth Secret"),
      '#description' => t("Client Secret given by MediaConnect"),
      '#default_value' => variable_get('connectid_oauth_secret', ''),
    ];
  }

  $form['oauth_info']['connectid_oauth_testing'] = [
    '#type' => 'checkbox',
    '#title' => t("Testing/Developer mode"),
    '#description' => t("Authenticate and query against Testing API"),
    '#default_value' => variable_get('connectid_oauth_testing', true),
  ];

  $form['connectid'] = [
    '#type'        => 'fieldset',
    '#title'       => t('ConnectID API Configuration'),
    '#description' => t("Configuration for the ConnectID API module."),
    '#tree'        => FALSE,
  ];

  $fieldset = &$form['connectid'];
  $fieldset['connectid_services'] = [
    '#type'        => 'fieldset',
    '#title'       => t('Enabled API Calls'),
    '#description' => t("Status of each API endpoint."),
    '#tree'        => FALSE,
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,
    '#attached'    => [
      'library' => [
        ['system', 'drupal.collapse'],
      ],
    ],
  ];

  $services = [
    'product'        => [
      'version' => 'v1',
    ],
    'profile'        => [
      'version' => 'v1',
    ],
    'customer'       => [
      'version' => 'v1',
    ],
    'order'          => [],
    'delivery'       => [],
    'deliveryStop'   => [],
    'complaint'      => [],
    'payment'        => [],
    'ticket'         => [],
    'address'        => [],
    'invoice'        => [],
    'invoiceAddress' => [],
    'category'       => [],
    'pbm'            => [],
    'status'         => [],
    'message'        => [],
    'subscription'   => [],
    'recruitment'    => [],
    'metadata'       => [],
    'privacy'        => [],
    'consent'        => [],
  ];

  /*
   * Populate the service status based on the info above.
   * If a service info is left empty, assume it's not implemented yet.
   */
  foreach ($services as $service => $info) {
    $key = _connectid_service_variable_key($service);

    $fieldset['connectid_services'][$key] = [
      '#type'          => 'checkbox',
      '#title'         => t(ucfirst($service)),
      '#default_value' => variable_get($key, FALSE),
    ];
    if (empty($info)) {
      $fieldset['connectid_services'][$key]['#attributes']['disabled'] = 'disabled';
      $fieldset['connectid_services'][$key]['#description'] = t("Not implemented");
    }
    else {
      $fieldset['connectid_services'][$key]['#description'] = t("Version: @ver %notes", [
        '@ver'   => $info['version'],
        '%notes' => isset($info['notes']) ? "({$info['notes']})" : '',
      ]);
    }
  }

  return system_settings_form($form);
}
