<?php

/**
 * Implements hook_connectid_login_oauth_pre_login().
 *
 * @param \ConnectID\Api\DataModel\ConnectIdProfile $profile
 *   The profile data from the API
 * @param array                                     $context
 */
function hook_connectid_login_oauth_pre_login(\ConnectID\Api\DataModel\ConnectIdProfile $profile, array $context) {
  // Check if the user is mapped in the system already.
  $account = user_external_load($context['external_id']);
  if (empty($account)) {
    // If not mapped tty to load based on the mail
    $account = user_load_by_mail($context['profile_email']);
    // If an existing user matches to the email, save the authmap to allow logging in with the correct user from conenctid.
    if (!empty($account) && $account->uid) {
      user_set_authmaps($account, ["authname_connectid_login" => $context['external_id']]);
    }
  }
}

/**
 * TODO: Write documentation for hook
 *
 * @param string $external_id
 * @param \ConnectID\Api\DataModel\ConnectIdProfile $profile
 */
function hook_connectid_login_profile_identifier_alter(string &$external_id, \ConnectID\Api\DataModel\ConnectIdProfile $profile) {
  // Prefer the "Email Credential" if available as external identifier
  if ($profile->isEmailCredential()) {
    $external_id = $profile->getCredential();
  }
}

/**
 * TODO: Write documentation for hook
 *
 * @param string $email
 * @param \ConnectID\Api\DataModel\ConnectIdProfile $profile
 */
function hook_connectid_login_profile_email_alter(string &$email, \ConnectID\Api\DataModel\ConnectIdProfile $profile) {
  // TODO
}

/**
 * TODO: Write documentation for hook
 *
 * @param string $full_name
 * @param \ConnectID\Api\DataModel\ConnectIdProfile $profile
 */
function hook_connectid_login_profile_name_alter(string &$full_name, \ConnectID\Api\DataModel\ConnectIdProfile $profile) {
  // Prefer the "email" as name or build one
  if ($profile->isEmailCredential()) {
    $full_name = $profile->getCredential();
  }
  else {
    $full_name = $full_name . '@' . $profile->getCredential();
  }
}
