<?php

function connectid_order_admin_report_page() {
  $build = [];

  $connectid = connectid_get_provider();
  if (!$connectid) {
    drupal_set_message(t("Unable to initiate ConnectID connection, information reported below are incomplete"), 'warning');
  }

  $orders = connectid_order_get_order_list();

  $rows = [];
  foreach ($orders as $order_id => $order) {
    $account = user_load($order->uid ?? 0);
    if (!empty($account->uid)) {
      $rows[$order_id]['user']['data'] = l($account->mail, 'user/' . $account->uid);
    }
    else {
      $rows[$order_id]['user']['data'] = "<em>" . t("Missing User") . "</em>";
    }

    $rows[$order_id]['order_id']['data'] = $order_id;

    $rows[$order_id]['created'] = [
      'data'  => format_date($order->created),
      'title' => 'Timestamp: ' . $order->created,
    ];

    $order_info = connectid_get_client_order_status($order_id);
    if ($order_info) {
      $rows[$order_id]['status'] = [
        'data' => $order_info->getOrderStatus(),
      ];
      $rows[$order_id]['total'] = [
        'data' => $order_info->getOrderAmount(),
      ];
    }
    else {
      $rows[$order_id]['status'] = t('Unknown');
      $rows[$order_id]['total'] = t('Unknown');
    }
  }

  $headers = [
    'user' => [
      'data' => t("User")
    ],
    'order_id' => [
      'data'=> t('Order ID')
    ],
    'created' => [
      'data' => t('Created at'),
    ],
  ];

  if ($connectid) {
    $headers['status'] = [
      'data' => t("Order status"),
    ];
    $headers['total'] = [
      'data' => t("Total value"),
    ];
  }

  $build['order_table'] = [
    '#theme' => 'table',
    '#header' => $headers,
    '#rows' => $rows,
  ];


  return $build;
}
